@@ -2,6 +2,7 @@
 Basic classes for typed wrappers over pandas dataframes
 """
 from itertools import chain
+import pytz
 
 import numpy as np
 import pandas as pd
@@ -15,6 +16,7 @@ except ImportError:
 dtype for datetime column
 """
 DATE_TIME_DTYPE = np.dtype('datetime64[ns]')
+UTC_DATE_TIME_DTYPE = pd.DatetimeTZDtype('ns', pytz.UTC)
 
 """
 dtype for string column
@@ -95,6 +97,8 @@ class TypedDataFrame:
                     df[col] = pd.Categorical(df[col], categories=expected[col], ordered=True)
                 elif expected[col] == DATE_TIME_DTYPE:
                     df[col] = pd.to_datetime(df[col])
+                elif expected[col] == UTC_DATE_TIME_DTYPE:
+                    df[col] = pd.to_datetime(df[col], utc=True)
                 else:
                     df[col] = df[col].astype(expected[col])
         
@@ -111,7 +115,7 @@ class TypedDataFrame:
         """
         return dict(chain(*(chain(cls.schema.items(), cls.optional.items())
                             if with_optional else cls.schema.items()
-                            for cls in cls.__mro__[:-1])))
+                            for cls in cls.__mro__[:-1] if hasattr(cls, 'schema'))))
 
     def __init__(self, df: pd.DataFrame):
 
@@ -157,7 +161,7 @@ class TypedDataFrame:
         assert all(object == c.values.categories.dtype for c in categoricals), msg
 
         addon = {col: dtype for col, dtype in self.dtype().items() if col not in df.columns}
-        self.df = df if len(addon) == 0 else pd.concat(
+        self.df: pd.DataFrame = df if len(addon) == 0 else pd.concat(
             [df, pd.DataFrame(columns=addon.keys()).astype(addon)], axis=1)
 
 
